ngff_zarr.itk_image_to_ngff_image - ngff-zarr
Description: Module Contents: Functions:,, itk_image_to_ngff_image, Convert an itk.Image or an itkwasm.Image to an NgffImage, preserving spatial metadata.,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.itk_image_to_ngff_image`

## Module Contents

### Functions

`itk_image_to_ngff_image` | Convert an itk.Image or an itkwasm.Image to an NgffImage, preserving spatial metadata.

### API

ngff_zarr.itk_image_to_ngff_image.itk_image_to_ngff_image(itk_image)

  Convert an itk.Image or an itkwasm.Image to an NgffImage, preserving spatial metadata.